# See-Do-Ku
A Computer Vision based interactive Sudoku Game using Hand Tracking for moving numbers across the frame. 

## Instructions

- Move your hand around the screen to control the pointer location
- Bring your hand closer towards the number you wish to pick up and your cursor for picking it up
- To move around a selected number without placing it in the grid, move your hand further from the screen and proceed to move the number
- To drop the number in it's desired place, bring your hand closer to the screen with the pointer at the same location. 

## Packages Used

- OpenCV 4.3.0
- Tensorflow 2.2
- Mediapipe
